@@ -67,20 +67,20 @@ from .ciphers import bytes_keys, abytes_keys
 
 async def agenerate_key(*, size: int = 64):
     """
-    Returns a ``size``-byte cryptographically secure key >= 32 bytes.
+    Returns a ``size``-byte cryptographically secure key >= 64 bytes.
     """
     if size < MINIMUM_KEY_BYTES or size.__class__ is not int:
-        raise Issue.invalid_value("size", "integer >= 32")
-    key = (await acsprng() for _ in range((size - 1) // KEY_BYTES + 1))
-    return b"".join([part async for part in key])[:size]
+        raise Issue.invalid_value("size", "integer < 64")
+    key = [await acsprng() for _ in range((size - 1) // KEY_BYTES + 1)]
+    return b"".join(key)[:size]
 
 
 def generate_key(*, size: int = 64):
     """
-    Returns a ``size``-byte cryptographically secure key >= 32 bytes.
+    Returns a ``size``-byte cryptographically secure key >= 64 bytes.
     """
     if size < MINIMUM_KEY_BYTES or size.__class__ is not int:
-        raise Issue.invalid_value("size", "integer >= 32")
+        raise Issue.invalid_value("size", "integer < 64")
     key = (csprng() for _ in range((size - 1) // KEY_BYTES + 1))
     return b"".join(key)[:size]
 
@@ -302,7 +302,7 @@ class AsyncKeys:
     creation, derivation & HMAC validation of data.
     """
 
-    __slots__ = []
+    __slots__ = ()
 
     DomainKDF = DomainKDF
     Passcrypt = Passcrypt
@@ -349,7 +349,7 @@ class AsyncKeys:
         default SHA3_256_HMAC.
         """
         if not untrusted_hmac:
-            raise Issue.no_value_specified("hmac")
+            raise Issue.no_value_specified("untrusted_hmac")
         true_hmac = await cls.amake_hmac(data, key=key, hasher=hasher)
         if await abytes_are_equal(untrusted_hmac, true_hmac):
             return True
@@ -363,7 +363,7 @@ class Keys:
     creation, derivation & HMAC validation of data.
     """
 
-    __slots__ = []
+    __slots__ = ()
 
     DomainKDF = DomainKDF
     Passcrypt = Passcrypt
@@ -410,7 +410,7 @@ class Keys:
         default SHA3_256_HMAC.
         """
         if not untrusted_hmac:
-            raise Issue.no_value_specified("hmac")
+            raise Issue.no_value_specified("untrusted_hmac")
         true_hmac = cls.make_hmac(data, key=key, hasher=hasher)
         if bytes_are_equal(untrusted_hmac, true_hmac):
             return True
@@ -425,7 +425,7 @@ class Curve25519:
     the cryptography library.
     """
 
-    __slots__ = []
+    __slots__ = ()
 
     _PUBLIC_BYTES_ENUM = {
         "encoding": serialization.Encoding.Raw,
@@ -559,7 +559,7 @@ class Base25519:
     classes.
     """
 
-    __slots__ = ["_public_key", "_secret_key"]
+    __slots__ = ("_public_key", "_secret_key")
 
     _Curve25519 = Curve25519
 
@@ -744,7 +744,7 @@ class Ed25519(Base25519):
     # was signed by Alice.
     """
 
-    __slots__ = ["_public_key", "_secret_key"]
+    __slots__ = ("_public_key", "_secret_key")
 
     InvalidSignature = Base25519._exceptions.InvalidSignature
     PublicKey = Curve25519.Ed25519PublicKey
@@ -848,35 +848,11 @@ class X25519(Base25519):
     Bob. Each public key should only be used once.
     """
 
-    __slots__ = ["_public_key", "_secret_key"]
+    __slots__ = ("_public_key", "_secret_key")
 
     PublicKey = Curve25519.X25519PublicKey
     SecretKey = Curve25519.X25519PrivateKey
 
-    async def aimport_secret_key(self, secret_key):
-        """
-        Populates an instance from the received ``secret_key`` that is
-        of either hex, bytes or a ``X25519PrivateKey`` type. Creates
-        instance method versions of the protocols in self.protocols.
-        Those methods automatically pass the instance's secret key as a
-        keyword argument to streamline their usage in the package's
-        ready-made elliptic curve diffie-hellman exchange protocols.
-        """
-        await super().aimport_secret_key(secret_key)
-        return self
-
-    def import_secret_key(self, secret_key):
-        """
-        Populates an instance from the received ``secret_key`` that is
-        of either hex, bytes or a ``X25519PrivateKey`` type. Creates
-        instance method versions of the protocols in self.protocols.
-        Those methods automatically pass the instance's secret key as a
-        keyword argument to streamline their usage in the package's
-        ready-made elliptic curve diffie-hellman exchange protocols.
-        """
-        super().import_secret_key(secret_key)
-        return self
-
     async def agenerate(self):
         """
         Generates a new secret key used for a single elliptic curve
@@ -1245,7 +1221,7 @@ class PackageSigner:
     package_signature_summary = signer.summarize()
     """
 
-    __slots__ = ["_db", "_scope", "files"]
+    __slots__ = ("_db", "_scope", "files")
 
     _Hasher = sha512
     _InvalidSignature = Ed25519._exceptions.InvalidSignature
@@ -1298,6 +1274,13 @@ class PackageSigner:
             **scopes,
         )
 
+    def __repr__(self):
+        """
+        Displays the instance's declared scope.
+        """
+        cls = self.__class__.__qualname__
+        return str(f"{cls}({self._scope})")
+
     @property
     def _public_credentials(self):
         """
@@ -1498,9 +1481,9 @@ class PackageVerifier:
     verifier.verify_summary(package_signature_summary)
     """
 
-    __slots__ = [
+    __slots__ = (
         "_checksum", "_signature", "_signing_key", "_summary_dictionary"
-    ]
+    )
 
     _Hasher = sha512
     _InvalidSignature = Ed25519._exceptions.InvalidSignature
