@@ -1,4 +1,4 @@
-# This file is part of aiootp, an asynchronous pseudo-one-time-pad based
+# This file is part of aiootp, an asynchronous pseudo one-time pad based
 # crypto and anonymity library.
 #
 # Licensed under the AGPLv3: https://www.gnu.org/licenses/agpl-3.0.html
@@ -40,9 +40,11 @@ for variable in __all__:
     __exports.append(variable)
 
 
-from test_Ropake import *
-for variable in __all__:
-    __exports.append(variable)
+# The Ropake class has been removed from the package pending changes to
+# the protocol & its implementation.
+# from test_Ropake import *
+# for variable in __all__:
+    # __exports.append(variable)
 
 
 from test_X25519_Ed25519 import *
